@@ -293,7 +293,6 @@ class Variable(pd.Series):
         """
         Initialize SAS variable metadata.
         """
-        # TODO: Consider validating that the name isn't blank.
         metadata = {
             'label': label,
             'vtype': vtype,
@@ -398,6 +397,7 @@ class Dataset(pd.DataFrame):
         'modified',
         'sas_os',
         'sas_version',
+        # TODO: Consider including dataset type: {'DATA', 'VIEW', ''}.
     ]
 
     def copy_metadata(self, other):
@@ -454,9 +454,6 @@ class Dataset(pd.DataFrame):
         """
         Initialize SAS dataset metadata.
         """
-        # TODO: Consider validating dataset type: {'DATA', 'VIEW', 'CATALOG'}.
-        #       I think only 'DATA' is supported by the XPORT format.
-        # TODO: Consider validating that the name isn't blank.
         metadata = {
             'name': name,
             'dataset_label': dataset_label,
@@ -783,6 +780,10 @@ class Reader:
         return getattr(self.dataset, name)
 
 
+class XportReader(Reader):
+    pass  # Alias.  https://github.com/selik/xport/issues/55
+
+
 class NamedTupleReader(Reader):
     pass  # Reader already yields namedtuples.
 
